Module: Google::Cloud::Bigquery::Connection
- Defined in:
- lib/google/cloud/bigquery/connection.rb,
lib/google/cloud/bigquery/connection/version.rb
Constant Summary collapse
- VERSION =
"1.6.2"
Class Method Summary collapse
-
.configure {|::Google::Cloud.configure.bigquery_connection| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-bigquery-connection library.
-
.connection_service(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for ConnectionService.
-
.connection_service_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the ConnectionService service is supported by the current client.
Class Method Details
.configure {|::Google::Cloud.configure.bigquery_connection| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-bigquery-connection library.
The following configuration parameters are supported:
credentials(type:String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.lib_name(type:String) - The library name as recorded in instrumentation and logging.lib_version(type:String) - The library version as recorded in instrumentation and logging.interceptors(type:Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.timeout(type:Numeric) - Default timeout in seconds.metadata(type:Hash{Symbol=>String}) - Additional headers to be sent with the call.retry_policy(type:Hash) - The retry policy. The value is a hash with the following keys::initial_delay(type:Numeric) - The initial delay in seconds.:max_delay(type:Numeric) - The max delay in seconds.:multiplier(type:Numeric) - The incremental backoff multiplier.:retry_codes(type:Array<String>) - The error codes that should trigger a retry.
147 148 149 150 151 |
# File 'lib/google/cloud/bigquery/connection.rb', line 147 def self.configure yield ::Google::Cloud.configure.bigquery_connection if block_given? ::Google::Cloud.configure.bigquery_connection end |
.connection_service(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for ConnectionService.
By default, this returns an instance of
Google::Cloud::Bigquery::Connection::V1::ConnectionService::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the ConnectionService service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the ConnectionService service. You can determine whether the method will succeed by calling connection_service_available?.
About ConnectionService
Manages external data source connections and credentials.
76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/google/cloud/bigquery/connection.rb', line 76 def self.connection_service version: :v1, transport: :grpc, &block require "google/cloud/bigquery/connection/#{version.to_s.downcase}" package_name = Google::Cloud::Bigquery::Connection .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::Bigquery::Connection.const_get(package_name).const_get(:ConnectionService) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.connection_service_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the ConnectionService service is supported by the current client. If true, you can retrieve a client object by calling connection_service. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the ConnectionService service, or if the versioned client gem needs an update to support the ConnectionService service.
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/google/cloud/bigquery/connection.rb', line 100 def self.connection_service_available? version: :v1, transport: :grpc require "google/cloud/bigquery/connection/#{version.to_s.downcase}" package_name = Google::Cloud::Bigquery::Connection .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::Bigquery::Connection.const_get package_name return false unless service_module.const_defined? :ConnectionService service_module = service_module.const_get :ConnectionService if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |